==> qt-everywhere-opensource-src-5.1.1.tar.xz: qt-everywhere-opensource-src-5.1.1/qtsensors/src/plugins/sensors/ios/iosmagnetometer.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef IOSMAGNETOMETER_H
#define IOSMAGNETOMETER_H

#include <Foundation/Foundation.h>

#include <qsensorbackend.h>
#include <qmagnetometer.h>

QT_BEGIN_NAMESPACE

class IOSMagnetometer : public QSensorBackend
{
public:
    static char const * const id;

    explicit IOSMagnetometer(QSensor *sensor);
    ~IOSMagnetometer();

    void start();
    void stop();

    void startMagnetometer();
    void startDeviceMotion();

private:
    NSOperationQueue *m_updateQueue;
    QMagnetometerReading m_reading;
};
QT_END_NAMESPACE

#endif // IOSMAGNETOMETER_H

==> qt-everywhere-opensource-src-5.2.0.tar.xz: qt-everywhere-opensource-src-5.2.0/qtsensors/src/plugins/sensors/ios/iosmagnetometer.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef IOSMAGNETOMETER_H
#define IOSMAGNETOMETER_H

#include <CoreMotion/CMMotionManager.h>

#include <qsensorbackend.h>
#include <qmagnetometer.h>

QT_BEGIN_NAMESPACE

class IOSMagnetometer : public QSensorBackend
{
public:
    static char const * const id;

    explicit IOSMagnetometer(QSensor *sensor);
    void timerEvent(QTimerEvent *);

    void start();
    void stop();

    void startMagnetometer();
    void startDeviceMotion();

private:
    CMMotionManager *m_motionManager;
    QMagnetometerReading m_reading;
    int m_timer;
    bool m_returnGeoValues;
};
QT_END_NAMESPACE

#endif // IOSMAGNETOMETER_H
